@@ -11,9 +11,14 @@ class FileWatchdog(FileSystemEventHandler):
     _observer: Observer
 
     def __init__(self, file_path: str, callback: Callable[..., None]):
+        """
+        Initialize the class.
+        :param file_path: the file path to monitor for changes
+        :param callback: the callback to invoke when changes are detected
+        """
         self.file_path = os.path.realpath(file_path)
         # https://github.com/python/mypy/issues/708
-        self.callback = callback  # type: ignore
+        self.callback = callback  # type: ignore[assignment]
 
         self._observer = Observer()
         self._observer.schedule(event_handler=self, path=os.path.dirname(file_path))
@@ -31,7 +36,10 @@ class FileWatchdog(FileSystemEventHandler):
         self._observer.stop()
 
     def on_modified(self, event: FileSystemEvent) -> None:
-        """Invoked when a modified event is generated."""
+        """
+        Invoked when a modified event is generated.
+        :param event: a watchdog event
+        """
         if not isinstance(event, FileModifiedEvent) or os.path.realpath(event.src_path) != self.file_path:
             return
         self.callback(self.file_path)
